@@ -5,7 +5,7 @@ package HTML::DeferableCSS;
 use v5.10;
 use Moo 1.006000;
 
-use Carp qw/ croak /;
+use Carp;
 use Devel::StrictMode;
 use File::ShareDir 1.112 qw/ dist_file /;
 use MooX::TypeTiny;
@@ -20,7 +20,7 @@ use Types::Standard qw/ Bool CodeRef HashRef Maybe Tuple /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.2.0';
+our $VERSION = 'v0.2.1';
 
 
 
@@ -28,6 +28,10 @@ has aliases => (
     is       => 'ro',
     isa      => STRICT ? HashRef [Maybe[SimpleStr]] : HashRef,
     required => 1,
+    coerce   => sub {
+        return { map { $_ => $_ } @{$_[0]} } if ref $_[0] eq 'ARRAY';
+        return $_[0];
+    },
 );
 
 
@@ -196,7 +200,11 @@ sub inline_html {
     $file //= $self->css_files->{$name};
     croak "invalid name '$name'" unless defined $file;
     if (my $path = $file->[PATH]) {
-        return "<style>" . $file->[PATH]->slurp_raw . "</style>";
+        if ($file->[SIZE]) {
+            return "<style>" . $file->[PATH]->slurp_raw . "</style>";
+        }
+        carp "empty file '$path'";
+        return "";
     }
     else {
         croak "'$name' refers to a URI";
@@ -206,11 +214,11 @@ sub inline_html {
 
 sub link_or_inline_html {
     my ($self, @names ) = @_;
-    foreach my $name (@names) {
+    foreach my $name (uniqstr @names) {
         croak "missing name" unless defined $name;
         my $file = $self->css_files->{$name};
         croak "invalid name '$name'" unless defined $file;
-        if ($file->[SIZE] <= $self->inline_max) {
+        if ( $file->[PATH] && ($file->[SIZE] <= $self->inline_max)) {
             return $self->inline_html($name, $file);
         }
         else {
@@ -226,7 +234,7 @@ sub deferred_link_html {
     my @deferred;
     for my $name (uniqstr @names) {
         my $file = $self->css_files->{$name} or croak "invalid name '$name'";
-        if ($file->[SIZE] <= $self->inline_max) {
+        if ($file->[PATH] && $file->[SIZE] <= $self->inline_max) {
             $buffer .= $self->inline_html($name, $file);
         }
         elsif ($self->defer_css) {
@@ -269,7 +277,7 @@ HTML::DeferableCSS - Simplify management of stylesheets in your HTML
 
 =head1 VERSION
 
-version v0.2.0
+version v0.2.1
 
 =head1 SYNOPSIS
 
@@ -355,7 +363,24 @@ omitted.
 
 If the name is the same as the filename (without the extension) than
 you can simply use C<1>.  (Likewise, an empty string or C<0> disables
-the alias.)
+the alias:
+
+  my $css = HTML::DeferableCSS->new(
+    aliases => {
+        reset => 1,
+        gone  => 0,       # using "gone" will throw an error
+        one   => "1.css", #
+    }
+    ...
+  );
+
+If all names are the same as their filenames, then an array reference
+can be used:
+
+  my $css = HTML::DeferableCSS->new(
+    aliases => [ qw( foo bar } ],
+    ...
+  );
 
 Absolute paths cannot be used.
 
@@ -386,11 +411,15 @@ tools for that.
 This is a hash reference used internally to translate L</aliases>
 into the actual files or URLs.
 
-If files cannot be found, then it will throw an error.
+If files cannot be found, then it will throw an error, so calling this
+attribute in void context can be used to check for any errors:
+
+  eval { $css->css_files } or die "$@";
 
 =head2 cdn_links
 
-This is a hash reference of L</aliases> to URLs.
+This is a hash reference of L</aliases> to URLs. (Only one URL per
+alias is supported.)
 
 When L</use_cdn_links> is true, then these URLs will be used instead
 of local versions.
@@ -485,6 +514,9 @@ This returns an embedded stylesheet referred to by C<$alias>.
 This returns either the link HTML markup, or the embedded stylesheet,
 if the file size is not greater than L</inline_max>.
 
+Note that a stylesheet will be inlined, even if there is are
+L</cdn_links>.
+
 =head2 deferred_link_html
 
   my $html = $css->deferred_link_html( @aliases );
